@@ -10,12 +10,12 @@ parseFuncs = getParseFuncs()
 parseFuncs = parseFuncs[names(parseFuncs) != 'pmid_status']
 
 test_that('parseElement returns no rows', {
-  for (i in 1:length(parseFuncs)) {
+  for (i in seq_len(length(parseFuncs))) {
     res = parseFuncs[[i]](pmXml, dPmid)
     if (data.table::is.data.table(res)) {
       expect_equal(nrow(res), 0L, label = names(parseFuncs)[i])
     } else {
-      for (j in 1:length(res)) {
+      for (j in seq_len(length(res))) {
         expect_equal(nrow(res[[j]]), 0L,
                      label = paste(names(parseFuncs)[i], names(res)[j]))}}}
 })
